==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/SelectorSyncSetSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SelectorSyncSetSpecBuilder extends SelectorSyncSetSpecFluentImpl<SelectorSyncSetSpecBuilder> implements VisitableBuilder<SelectorSyncSetSpec,SelectorSyncSetSpecBuilder>{
  public SelectorSyncSetSpecBuilder() {
    this(false);
  }
  public SelectorSyncSetSpecBuilder(Boolean validationEnabled) {
    this(new SelectorSyncSetSpec(), validationEnabled);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SelectorSyncSetSpec(), validationEnabled);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent,SelectorSyncSetSpec instance) {
    this(fluent, instance, false);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent,SelectorSyncSetSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApplyBehavior(instance.getApplyBehavior());
      fluent.withClusterDeploymentSelector(instance.getClusterDeploymentSelector());
      fluent.withPatches(instance.getPatches());
      fluent.withResourceApplyMode(instance.getResourceApplyMode());
      fluent.withResources(instance.getResources());
      fluent.withSecretMappings(instance.getSecretMappings());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpec instance) {
    this(instance,false);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApplyBehavior(instance.getApplyBehavior());
      this.withClusterDeploymentSelector(instance.getClusterDeploymentSelector());
      this.withPatches(instance.getPatches());
      this.withResourceApplyMode(instance.getResourceApplyMode());
      this.withResources(instance.getResources());
      this.withSecretMappings(instance.getSecretMappings());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  SelectorSyncSetSpecFluent<?> fluent;
  Boolean validationEnabled;
  public SelectorSyncSetSpec build() {
    SelectorSyncSetSpec buildable = new SelectorSyncSetSpec(fluent.getApplyBehavior(),fluent.getClusterDeploymentSelector(),fluent.getPatches(),fluent.getResourceApplyMode(),fluent.getResources(),fluent.getSecretMappings());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/SelectorSyncSetSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SelectorSyncSetSpecBuilder extends SelectorSyncSetSpecFluent<SelectorSyncSetSpecBuilder> implements VisitableBuilder<SelectorSyncSetSpec,SelectorSyncSetSpecBuilder>{
  public SelectorSyncSetSpecBuilder() {
    this(false);
  }
  public SelectorSyncSetSpecBuilder(Boolean validationEnabled) {
    this(new SelectorSyncSetSpec(), validationEnabled);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SelectorSyncSetSpec(), validationEnabled);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent,SelectorSyncSetSpec instance) {
    this(fluent, instance, false);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent,SelectorSyncSetSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new SelectorSyncSetSpec());

    if (instance != null) {
      fluent.withApplyBehavior(instance.getApplyBehavior());
      fluent.withClusterDeploymentSelector(instance.getClusterDeploymentSelector());
      fluent.withPatches(instance.getPatches());
      fluent.withResourceApplyMode(instance.getResourceApplyMode());
      fluent.withResources(instance.getResources());
      fluent.withSecretMappings(instance.getSecretMappings());
      fluent.withApplyBehavior(instance.getApplyBehavior());
      fluent.withClusterDeploymentSelector(instance.getClusterDeploymentSelector());
      fluent.withPatches(instance.getPatches());
      fluent.withResourceApplyMode(instance.getResourceApplyMode());
      fluent.withResources(instance.getResources());
      fluent.withSecretMappings(instance.getSecretMappings());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpec instance) {
    this(instance,false);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new SelectorSyncSetSpec());

    if (instance != null) {
      this.withApplyBehavior(instance.getApplyBehavior());
      this.withClusterDeploymentSelector(instance.getClusterDeploymentSelector());
      this.withPatches(instance.getPatches());
      this.withResourceApplyMode(instance.getResourceApplyMode());
      this.withResources(instance.getResources());
      this.withSecretMappings(instance.getSecretMappings());
      this.withApplyBehavior(instance.getApplyBehavior());
      this.withClusterDeploymentSelector(instance.getClusterDeploymentSelector());
      this.withPatches(instance.getPatches());
      this.withResourceApplyMode(instance.getResourceApplyMode());
      this.withResources(instance.getResources());
      this.withSecretMappings(instance.getSecretMappings());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  SelectorSyncSetSpecFluent<?> fluent;
  Boolean validationEnabled;
  public SelectorSyncSetSpec build() {
    SelectorSyncSetSpec buildable = new SelectorSyncSetSpec(fluent.getApplyBehavior(),fluent.buildClusterDeploymentSelector(),fluent.buildPatches(),fluent.getResourceApplyMode(),fluent.getResources(),fluent.buildSecretMappings());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
